#version 3.61;

#include "shapes.inc"
#include "metals.inc"
#include "glass.inc"
#include "colors.inc"

#declare Use_Photons = 10;
#declare Load_Photons = 0;
#declare Photon_File = "laser_test.ph";


/*
photons {
  spacing <photon_spacing> | count <photons_to_shoot>

  [gather <min_gather>, <max_gather>]
  [media <max_steps> [,<factor>]]
  [jitter <jitter_amount>]
  [max_trace_level <photon_trace_level>]
  [adc_bailout <photon_adc_bailout>]
  [save_file "filename" | load_file "filename"]
  [autostop <autostop_fraction>]
  [expand_thresholds <percent_increase>, <expand_min>]
  [radius <gather_radius>,<multiplier>,
          <gather_radius_media>,<multiplier>]
}
*/

global_settings {
  assumed_gamma 1.0
  max_trace_level 7
  #if(Use_Photons)
    photons {
      spacing 0.05
      media 200
      max_trace_level 7
      adc_bailout 1/256
      #if(Load_Photons & file_exists(Photon_File))
        load_file Photon_File
      //#else
      //  save_file Photon_File
      #end
    }
  #end
}

camera {
  location <0, 80, -150>
  up y
  right x * image_width/image_height
  look_at 0

  angle 22
}

#declare laser =
light_source {
  <22,2,22>, <.4,0,1>*120
  cylinder
  point_at <-20,2,22>
  radius .1
  falloff .4
  tightness 0.25
  photons {
    reflection on
    refraction on
  }
}
#declare laser2 =
light_source {
  <-50,2,-10>, <.3,0,1>*40
  cylinder
  point_at <20,2,-10>
  radius 1
  falloff 2
  tightness 0.25
  photons {
    reflection on
    refraction on
  }
}


#declare reflector = object {
Round_Box_Union(<-0.8, 0, -4>, <0, 4, 4>, 0.25)

  pigment { rgb .2 }
  finish {
    ambient .1
    diffuse .6
    reflection { 1 }
  } 
  photons {
    target
    reflection on
    refraction on
  }
  
}
#declare _z_ = -<44,36,0>;
#declare _x_ = vnormalize(vcross(y,_z_))*10;
#declare _y_ = vnormalize(vcross(_z_,_x_))*10;

//light_group {
#if (10)
  light_source { <44,36,0> color rgb <.22,.88,.99>*.7
    area_light _x_,_y_, 13,13 adaptive 0 jitter orient circular
    media_interaction off media_attenuation off
  }
#else
  light_source {
   <27.5,36.1,-43.8> rgb <.82,.88,.99>*.6
   media_interaction off media_attenuation off 
  }  
#end 
//}
//#include "triangulation.inc"
//#declare lightgun =
merge {
  cylinder { <0,0,0>, <0,4,0> 1  open rotate z*-90 }
  cylinder { <0,0,0>, <0,1.5,0> 0.7 translate <2,-2,0> }

  texture { T_Chrome_3C } 
  translate <22.5,2,22>
}

//#declare table  =
object {
  Round_Box_Union(<-30, -0.6, -30>, <30, 0, 30>, 0.25)
  pigment { color Gray60 }
  finish {  ambient .1 diffuse .6 }
}


//right side at zero
//object { reflector rotate y*45 translate z*22}
//object { reflector rotate y*-135 }


#declare trget = box {
  <-0.5, -8, -8>, <0.5, 8, 8>
  pigment { White }
  rotate z * 90
  translate  <-9, 9, 0>
}

#declare Scatter_M =
  material {
    texture {
      pigment { rgbt 1 }
      finish {
        ambient 0
        diffuse 0
      }
    }
    interior {
      media {
        method 3
        intervals 1
        samples 70, 1000
        scattering {
          1, rgb 0.1
          extinction 0.00001
        }
      }
    }
  }
#declare m_glass = 
material { texture {
    pigment { rgbf <1.0, 1.0, 1.0,.9> }
    finish { F_Glass3 } }
  interior { I_Glass }
}
  
#declare concav_glass = 
difference { cylinder { <-2,0,0>,<2,0,0> 2 }
  //box { <-1, -2, -2>, <1, 2, 2> }
  sphere { <3.05,0,0>, 3 } sphere { <-3.05,0,0>, 3 }
  material { m_glass } photons { target reflection on refraction on }
} 
#declare concav_glass66 = 
difference { cylinder { <-2,0,0>,<2,0,0> 2 }
  sphere { <6.05,0,0>, 6 } 
  sphere { <-6.05,0,0>, 6 }
  material { m_glass } photons { target reflection on refraction on }
}
#declare concav_glass55 = 
difference { cylinder { <-2,0,0>,<2,0,0> 2 }
  sphere { <5.05,0,0>, 5 } sphere { <-5.05,0,0>, 5 }
  material { m_glass } photons { target reflection on refraction on }
}
#declare concav_glass3 = 
difference { cylinder { <-2,0,0>,<2,0,0> 2 } 
  //sphere {  <5.1,0,0>, 5 }
  box { <.1,-3,-3>, <3, 3, 3> } sphere { <-3.3,0,0>, 3.2 }
  material { m_glass } photons { target reflection on refraction on }
}
#declare concav_glass5 = 
difference { cylinder { <-.5,0,0>,<.5,0,0> 2 } 
  //sphere { <5.1,0,0>, 5 }
  box { <0,-3,-3>, <3, 3, 3> }
  //sphere { <-4.6,0,0>, 4.5 }
  sphere { <-5.1,0,0>, 5 }
  //sphere { <-2.1,0,0>, 2 }
  //sphere { <-6.1,0,0>, 6 }
  material { m_glass } photons { target reflection on refraction on }
}
//object { concav_glass66 translate <9.7,2,-10> }


#declare concav_glass1 = 
difference { cylinder { <-.5,0,0>,<.5,0,0> 2 }
  sphere { <1.85,0,0>, 1.75 } sphere { <-1.85,0,0>, 1.75 }
  material { m_glass } photons { target reflection on refraction on }
}
object { concav_glass1 translate <8.645,2,-10> } // not focused    8.64 r 1.75
#declare concav_glass21 = 
difference { cylinder { <-.5,0,0>,<.5,0,0> 2 }
  sphere { <2,0,0>, 1.9 } sphere { <-2,0,0>, 1.9 }
  material { m_glass } photons { target reflection on refraction on }
}
//object { concav_glass21 translate <9.2,2,-10> }

#declare maglass = 
intersection {
sphere {  <3.2,0,0>, 4 }
sphere {  <-3.2,0,0>, 4 }
  material { m_glass } photons { target reflection on refraction on }
}
object { maglass translate <6,2,-10> }

#declare con_reflector = 
difference {
  sphere {  0, 4 }
  box { <-5, -5, -2>, <5, 5, 5> }

  pigment { rgb .2 }
  finish {
    ambient .1
    diffuse .6
    reflection { 1 }
  } 
  photons {
    target
    reflection on
    refraction on
  }

}
#declare concav_reflector = 
difference {
  sphere {  0, 4 }
  sphere {  0, 5 translate z*2 }

  pigment { rgb .2 }
  finish {
    ambient .1
    diffuse .6
    reflection { 1 }
  } 
  photons {
    target
    reflection on
    refraction on
  }

}

object { con_reflector 
  translate z*2
  rotate y*135
  translate <0,2,22>
}

object { con_reflector 
  translate z*2
  rotate y*-45
  translate <0,2,0>
}

object { con_reflector 
  translate z*2
  rotate y*135
  translate x*-15
  translate <0,2,0>
}
#declare concav_ =
object { concav_reflector
  translate z*3
  rotate y*45
  translate x*-15 translate z*-10
  translate <0,2,0>
}


#declare container =
sphere {  0, 60
  hollow
  material { Scatter_M }
  photons {
    pass_through
  }
}
object { container }


#declare _prism = prism {
linear_sweep
bezier_spline
0.44, //top
0.0, //bottom
12 ,
<0.22,0>,<-0.22,0>,<0.22,0>,<-0.22,0>,
<-0.22,0>,<0.0,0.38106>,<-0.22,0>,<0.0,0.38106>,
<0.0,0.38106>,<0.22,0>,<0.0,0.38106>,<0.22,0>
}

#declare aprism =
object { _prism scale 10 
  texture {
    pigment { rgbf <1.0, 1.0, 1.0,.9> }
    finish { F_Glass3 }
  }
  interior { I_Glass }

  photons {
    target
    reflection on
    refraction on
  }
}
//object { aprism rotate y*135 translate <0,0,22> }
//object { aprism translate <6,0,-12> }



//light_source { laser }
light_source { laser2 }
